EXPORTS
	??1CA2dpBTHeadsetAudioInterface@@UAE@XZ @ 1 NONAME ; CA2dpBTHeadsetAudioInterface::~CA2dpBTHeadsetAudioInterface(void)
	?BytesPlayed@CA2dpBTHeadsetAudioInterface@@QBEIXZ @ 2 NONAME ; unsigned int CA2dpBTHeadsetAudioInterface::BytesPlayed(void) const
	?CancelInitialize@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 3 NONAME ; void CA2dpBTHeadsetAudioInterface::CancelInitialize(void)
	?CancelNotifyError@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 4 NONAME ; void CA2dpBTHeadsetAudioInterface::CancelNotifyError(void)
	?CancelOpenDevice@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 5 NONAME ; void CA2dpBTHeadsetAudioInterface::CancelOpenDevice(void)
	?CancelPlayData@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 6 NONAME ; void CA2dpBTHeadsetAudioInterface::CancelPlayData(void)
	?CloseDevice@CA2dpBTHeadsetAudioInterface@@QAEXAAVTRequestStatus@@@Z @ 7 NONAME ; void CA2dpBTHeadsetAudioInterface::CloseDevice(class TRequestStatus &)
	?FlushBuffer@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 8 NONAME ; void CA2dpBTHeadsetAudioInterface::FlushBuffer(void)
	?GetSupportedChannels@CA2dpBTHeadsetAudioInterface@@QBEHAAV?$RArray@I@@AAW4TMMFStereoSupport@@@Z @ 9 NONAME ; int CA2dpBTHeadsetAudioInterface::GetSupportedChannels(class RArray<unsigned int> &, enum TMMFStereoSupport &) const
	?GetSupportedDataTypes@CA2dpBTHeadsetAudioInterface@@QBEHAAV?$RArray@VTFourCC@@@@@Z @ 10 NONAME ; int CA2dpBTHeadsetAudioInterface::GetSupportedDataTypes(class RArray<class TFourCC> &) const
	?GetSupportedSampleRates@CA2dpBTHeadsetAudioInterface@@QBEHAAV?$RArray@I@@AAV?$RArray@VTRange@@@@@Z @ 11 NONAME ; int CA2dpBTHeadsetAudioInterface::GetSupportedSampleRates(class RArray<unsigned int> &, class RArray<class TRange> &) const
	?Initialize@CA2dpBTHeadsetAudioInterface@@QAEXABVTBTDevAddr@@AAVTRequestStatus@@@Z @ 12 NONAME ; void CA2dpBTHeadsetAudioInterface::Initialize(class TBTDevAddr const &, class TRequestStatus &)
	?NewL@CA2dpBTHeadsetAudioInterface@@SAPAV1@XZ @ 13 NONAME ; class CA2dpBTHeadsetAudioInterface * CA2dpBTHeadsetAudioInterface::NewL(void)
	?NotifyError@CA2dpBTHeadsetAudioInterface@@QAEXAAVTRequestStatus@@@Z @ 14 NONAME ; void CA2dpBTHeadsetAudioInterface::NotifyError(class TRequestStatus &)
	?OpenDevice@CA2dpBTHeadsetAudioInterface@@QAEXAAVTRequestStatus@@@Z @ 15 NONAME ; void CA2dpBTHeadsetAudioInterface::OpenDevice(class TRequestStatus &)
	?PauseBuffer@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 16 NONAME ; void CA2dpBTHeadsetAudioInterface::PauseBuffer(void)
	?PlayData@CA2dpBTHeadsetAudioInterface@@QAEXABVTDesC8@@AAVTRequestStatus@@@Z @ 17 NONAME ; void CA2dpBTHeadsetAudioInterface::PlayData(class TDesC8 const &, class TRequestStatus &)
	?ResetBytesPlayed@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 18 NONAME ; void CA2dpBTHeadsetAudioInterface::ResetBytesPlayed(void)
	?ResumePlaying@CA2dpBTHeadsetAudioInterface@@QAEXXZ @ 19 NONAME ; void CA2dpBTHeadsetAudioInterface::ResumePlaying(void)
	?SetChannels@CA2dpBTHeadsetAudioInterface@@QAEHIW4TMMFStereoSupport@@@Z @ 20 NONAME ; int CA2dpBTHeadsetAudioInterface::SetChannels(unsigned int, enum TMMFStereoSupport)
	?SetDataType@CA2dpBTHeadsetAudioInterface@@QAEHABVTFourCC@@@Z @ 21 NONAME ; int CA2dpBTHeadsetAudioInterface::SetDataType(class TFourCC const &)
	?SetSampleRate@CA2dpBTHeadsetAudioInterface@@QAEHI@Z @ 22 NONAME ; int CA2dpBTHeadsetAudioInterface::SetSampleRate(unsigned int)
	?SetVolume@CA2dpBTHeadsetAudioInterface@@QAEHI@Z @ 23 NONAME ; int CA2dpBTHeadsetAudioInterface::SetVolume(unsigned int)
	?TEST_ForceRemoteSBCCodecConfiguration@CA2dpBTHeadsetAudioInterface@@QAEXABVTSBCCodecCapabilities@@@Z @ 24 NONAME ; void CA2dpBTHeadsetAudioInterface::TEST_ForceRemoteSBCCodecConfiguration(class TSBCCodecCapabilities const &)
	?TEST_MGavdpUser@CA2dpBTHeadsetAudioInterface@@QAEPAVMGavdpUser@@XZ @ 25 NONAME ; class MGavdpUser * CA2dpBTHeadsetAudioInterface::TEST_MGavdpUser(void)
	?Volume@CA2dpBTHeadsetAudioInterface@@QBEIXZ @ 26 NONAME ; unsigned int CA2dpBTHeadsetAudioInterface::Volume(void) const

